@@ -31,6 +31,8 @@ class MessageType(NamedEnum):
     NOTICE = auto()
     BOT_PERMANENTLY_BANNED = auto()
     BOT_TIMED_OUT = auto()
+    USER_STATE = auto()
+    ROOM_STATE = auto()
     NONE = auto()
 
 
@@ -74,6 +76,8 @@ class Event(NamedEnum):
     on_pubsub_user_follow = auto()
     on_bot_shutdown = auto()
     on_after_database_init = auto()
+    on_room_state = auto()
+    on_user_state = auto()
 
 
 class SubtractBalanceResult(NamedEnum):
