@@ -42,7 +42,6 @@ class Message:
         self.reward: Optional[str] = None
         self.msg_id: Optional[str] = None
         self.timeout_seconds: Optional[int] = None
-
         self._parse()
 
     @classmethod
@@ -216,9 +215,13 @@ class Message:
                 # bits and rewards cannot be combined, so return here
                 return True
 
-            # checking if its a channel point redemption
-            self.reward = self.tags.all_tags.get('msg-id') or self.tags.all_tags.get('custom-reward-id')
-            if self.reward is not None:
+            # checking if its a channel point redemption or another special message
+            self.reward = self.tags.msg_id or self.tags.all_tags.get('custom-reward-id')
+            # prevent power-ups and animated messages from being treated as channel point redemptions
+            if self.reward in ('animated-message', 'gigantified-emote-message'):
+                pass
+            # message is not an animated message, so it's probably a channel point redemption
+            elif self.reward is not None:
                 self.type = MessageType.CHANNEL_POINTS_REDEMPTION
 
         return bool(m)
@@ -288,6 +291,22 @@ class Message:
     def is_raid(self):
         return self.type is MessageType.RAID
 
+    @property
+    def is_animated_message(self):
+        return bool(self.tags.animation_id)
+
+    @property
+    def has_gigantified_emote(self):
+        return self.tags.msg_id == 'gigantified-emote-message'
+
+    @property
+    def gigantified_emote(self):
+        return self.parts[-1]
+
+    @property
+    def has_power_up(self):
+        return self.is_animated_message or self.has_gigantified_emote
+
     @property
     def mention(self):
         return f'@{self.tags.display_name}' if self.tags.display_name else self.mention_normalized
